<?php
/*
Plugin Name: BitMate Author Donations
Plugin URI: http://bitmate.net/author-donations/
Description: Adds a bitcoin address field to user profiles so that authors can accept bitcoin donations via an automatically generated bitcoin donation box after their posts.
Version: 1.1.2
Author: BitMate
Author URI: http://bitmate.net
License: GPLv2 or later
*/

/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

/* Register and Enqueue Bitmate Author Donations Stylesheet */
add_action( 'wp_enqueue_scripts', 'bm_author_donations_stylesheet' );

function bm_author_donations_stylesheet() {
    wp_register_style( 'bm-author-donations-style', plugins_url('style.css', __FILE__) );
    wp_enqueue_style( 'bm-author-donations-style' );
}

/* Add Bitcoin Meta Field to User Profiles */
add_action( 'show_user_profile', 'bm_profile_bitcoin_field' );
add_action( 'edit_user_profile', 'bm_profile_bitcoin_field' );

function bm_profile_bitcoin_field( $user ) { ?>
	<h3>BitMate Donation Information</h3>
	<table class="form-table">
		<tr>
			<th><label for="bitcoin">Bitcoin</label></th>
			<td>
				<input type="text" name="bitcoin" id="bitcoin" value="<?php echo esc_attr( get_the_author_meta( 'bitcoin', $user->ID ) ); ?>" class="regular-text" /><br />
				<span class="description">Please enter your bitcoin address.</span>
			</td>
		</tr>
	</table>
<?php }

/* Save BitMate Meta Data on User Profiles */
add_action( 'personal_options_update', 'bm_save_profile_bitcoin_field' );
add_action( 'edit_user_profile_update', 'bm_save_profile_bitcoin_field' );

function bm_save_profile_bitcoin_field( $user_id ) {
	if ( !current_user_can( 'edit_user', $user_id ) )
		return false;
	update_user_meta( $user_id, 'bitcoin', $_POST['bitcoin'] );
}

/* Add BitMate Donation Box After Posts */
add_filter( 'the_content', 'bm_author_donation_box' );

function bm_author_donation_box($content) {

	$display_options = get_option( 'bitmate_author_donations_display_options' );

	if( isset( $display_options['display_bm_post_box'] ) && $display_options[ 'display_bm_post_box' ] && !is_page() ) { 

		$bm_site_name = get_bloginfo( 'name' );
		$bm_author_name = get_the_author_meta( 'display_name' );
		$bm_post_url = get_permalink();
		$bm_author_bitcoin = get_the_author_meta( 'bitcoin' );
		$bm_author_donate_url = 'bitcoin:'. $bm_author_bitcoin.'?label=Donation-from%3A'. urlencode($bm_post_url) .'&message=Donation-from%3A'. urlencode($bm_post_url) .'';
		
		if( isset( $display_options['display_bm_author_credit'] ) && $display_options[ 'display_bm_author_credit' ] ) {
			$bm_author_credit = '<br/><small class="bitmate-author-credit"><a href="http://bitmate.net/author-donations/" rel="nofollow" class="bitmate-author-credit">Powered by BitMate Author Donations</a></small>';
		} else {
			$bm_author_credit = '';
		}
		
		$bm_donation_box='
			<div class="bitmate-author-donation">
				<div class="bitmate-author-scan">
					<a href="'.$bm_author_donate_url.'" title="Scan to Donate Bitcoin to '.$bm_author_name.'"><img src="http://chart.googleapis.com/chart?chs=150x150&cht=qr&chld=H|0&chl='.$bm_author_donate_url.'" alt="Scan to Donate Bitcoin" /></a>
				</div>
				<div class="bitmate-author-description">
					<strong>Like this?</strong> Donate Bitcoin to <a href="'. get_author_posts_url( get_the_author_meta( 'ID' ) ) .'" title="'. $bm_author_name .'" rel="author">'. $bm_author_name .'</a> at:
					<br/>
					<a href="'.$bm_author_donate_url.'" title="Donate Bitcoin to '. $bm_author_name .'"><img src="'.plugins_url( 'images/bitcoin.png' , __FILE__ ).'" alt="Bitcoin" /> <strong>'. $bm_author_bitcoin .'</strong></a></a>
					<br/>
					<a href="'.$bm_author_donate_url.'" title="Donate Bitcoin to '.$bm_author_name.'"><img src="'.plugins_url( 'images/donate.png' , __FILE__ ).'" alt="Donate" class="bitmate-author-donate-button"/></a>
					'. $bm_author_credit .'					
				</div>
			</div>
		';
		
		if ( get_the_author_meta( 'bitcoin' ) ) { 
			return $content.= ($bm_donation_box);
		} 
	
	} else {
		return $content;
	}
}

/* Add BitMate Donation Box Shortcode */
function bm_author_donate_shortcode() {

	$bm_site_name = get_bloginfo( 'name' );
	$bm_author_name = get_the_author_meta( 'display_name' );
	$bm_post_url = get_permalink();
	$bm_author_bitcoin = get_the_author_meta( 'bitcoin' );
	$bm_author_donate_url = 'bitcoin:'. $bm_author_bitcoin.'?label=Donation-from%3A'. urlencode($bm_post_url) .'&message=Donation-from%3A'. urlencode($bm_post_url) .'';
	
	$bm_donation_box='
		<div class="bitmate-author-donation">
			<div class="bitmate-author-scan">
				<a href="'.$bm_author_donate_url.'" title="Scan to Donate Bitcoin to '.$bm_author_name.'"><img src="http://chart.googleapis.com/chart?chs=150x150&cht=qr&chld=H|0&chl='.$bm_author_donate_url.'" alt="Scan to Donate Bitcoin" /></a>
			</div>
			<div class="bitmate-author-description">
				<strong>Like this?</strong> Donate Bitcoin to <a href="'. get_author_posts_url( get_the_author_meta( 'ID' ) ) .'" title="'. $bm_author_name .'" rel="author">'. $bm_author_name .'</a> at:
				<br/>
				<a href="'.$bm_author_donate_url.'" title="Donate Bitcoin to '. $bm_author_name .'"><img src="'.plugins_url( 'images/bitcoin.png' , __FILE__ ).'" alt="Bitcoin" /> <strong>'. $bm_author_bitcoin .'</strong></a></a>
				<br/>
				<a href="'.$bm_author_donate_url.'" title="Donate Bitcoin to '.$bm_author_name.'"><img src="'.plugins_url( 'images/donate.png' , __FILE__ ).'" alt="Donate" class="bitmate-author-donate-button"/></a>
			</div>
		</div>
	';
		
	if ( get_the_author_meta( 'bitcoin' ) ) { 
		return $bm_donation_box;
	} 
}
add_shortcode( 'bitmate-author-donate', 'bm_author_donate_shortcode' );

/* Builds BitMate Donation Widget */
function bm_donate_widget_shortcode() {

	$bm_site_name = get_bloginfo( 'name' );
	$bm_author_name = get_the_author_meta( 'display_name' );
	$bm_post_url = get_permalink();
	$bm_author_bitcoin = get_the_author_meta( 'bitcoin' );
	$bm_author_donate_url = 'bitcoin:'. $bm_author_bitcoin.'?label=Donation-from%3A'. urlencode($bm_post_url) .'&message=Donation-from%3A'. urlencode($bm_post_url) .'';
	
	$bm_donation_box='
		<div class="bitmate-author-donation">
			<div class="bitmate-author-scan">
				<a href="'.$bm_author_donate_url.'" title="Scan to Donate Bitcoin to '.$bm_author_name.'"><img src="http://chart.googleapis.com/chart?chs=150x150&cht=qr&chld=H|0&chl='.$bm_author_donate_url.'" alt="Scan to Donate Bitcoin" /></a>
			</div>
			<div class="bitmate-author-description">
				<strong>Like this?</strong> Donate Bitcoin to <a href="'. get_author_posts_url( get_the_author_meta( 'ID' ) ) .'" title="'. $bm_author_name .'" rel="author">'. $bm_author_name .'</a> at:
				<br/>
				<a href="'.$bm_author_donate_url.'" title="Donate Bitcoin to '. $bm_author_name .'"><img src="'.plugins_url( 'images/bitcoin.png' , __FILE__ ).'" alt="Bitcoin" /> <strong>'. $bm_author_bitcoin .'</strong></a></a>
				<br/>
				<a href="'.$bm_author_donate_url.'" title="Donate Bitcoin to '.$bm_author_name.'"><img src="'.plugins_url( 'images/donate.png' , __FILE__ ).'" alt="Donate" class="bitmate-author-donate-button"/></a>
			</div>
		</div>
	';
		
	if ( get_the_author_meta( 'bitcoin' ) ) { 
		return $bm_donation_box;
	} 
}
add_shortcode( 'bitmate-donate-widget', 'bm_donate_widget_shortcode' );

/* Add BitMate Author Donations Settings Page */
function bm_author_donations_menu() {
	add_menu_page(
		'BitMate Author Donations Settings',
		'BitMate',
		'administrator',			
		'bm_settings',
		'bm_author_donations_settings_display',
		plugins_url( 'images/bitcoin.png' , __FILE__ )
	);
} 
add_action('admin_menu', 'bm_author_donations_menu');

/* Renders BitMate Author Donations Settings Page */
function bm_author_donations_settings_display() {
?>
	<div class="wrap">
		<div id="icon-themes" class="icon32"></div>
		<h2>BitMate Author Donations Settings</h2>

		<?php settings_errors(); ?> 
	
		<form method="post" action="options.php">
			<?php settings_fields( 'bitmate_author_donations_display_options' ); ?>
			<?php do_settings_sections( 'bitmate_author_donations_display_options' ); ?>
			<?php submit_button(); ?>
		</form>
		
		<div style="margin-top:50px;">
			<div style="float:left;margin-right:20px;">
				<a href="bitcoin:129rYbXVG9BKgsdJ1FMfXQX1gatDmViMgi?label=BitMateAuthorDonation&message=BitMateAuthorDonation" title="Scan to Donate Bitcoin to BitMate"><img src="http://chart.googleapis.com/chart?chs=150x150&cht=qr&chld=H|0&chl=bitcoin:129rYbXVG9BKgsdJ1FMfXQX1gatDmViMgi?label=BitMateAuthorDonation&message=BitMateAuthorDonation" alt="Scan to Donate Bitcoin to BitMate" /></a>
			</div>
			<div style="float:left;width:400px;text-align:center;">
				<strong>Like this plugin?</strong> Donate Bitcoin to BitMate at:
				<br/><br/>
				<span style="margin: 25px 0px 25px 0px;"><a href="bitcoin:129rYbXVG9BKgsdJ1FMfXQX1gatDmViMgi?label=BitMateAuthorDonation&message=BitMateAuthorDonation" title="Donate Bitcoin to BitMate"><img src="<?php echo plugins_url( 'images/bitcoin.png' , __FILE__ ); ?>" alt="Bitcoin" /> <strong>129rYbXVG9BKgsdJ1FMfXQX1gatDmViMgi</strong></a></span>
				<br/><br/>
				<a href="bitcoin:129rYbXVG9BKgsdJ1FMfXQX1gatDmViMgi?label=BitMateAuthorDonation&message=BitMateAuthorDonation" title="Donate Bitcoin to '.$bm_author_name.'"><img src="<?php echo plugins_url( 'images/donate.png' , __FILE__ ); ?>" alt="Donate" /></a>
			</div>
			<div style="clear:both;"><br/><p>You May also want to: <strong><a href="https://facebook.com/BitMate">Like us on Facebook</a></strong> and <strong><a href="https://twitter.com/bitmate">Follow us on Twitter</a></strong></p></div>
		</div>
	</div>
<?php
} 

/* Provides default values for the Display Options */
function bitmate_author_donations_default_display_options() {

	$defaults = array(
		'display_bm_post_box'		=>	'',
		'display_bm_author_credit'		=>	''
	);

	return apply_filters( 'bitmate_author_donations_default_display_options', $defaults );
}

function bm_author_donations_options() { 

	if( false == get_option( 'bitmate_author_donations_display_options' ) ) {	
		add_option( 'bitmate_author_donations_display_options', apply_filters( 'bitmate_author_donations_default_display_options', bitmate_author_donations_default_display_options() ) );
	}
 
    add_settings_section( 
        'bitmate_author_donations', 
        'Display Settings',  
        'bm_author_donations_options_callback', 
        'bitmate_author_donations_display_options'  
    ); 
     
    add_settings_field(   
        'display_bm_post_box', 
        'BitMate Author Donations Post Box',  
        'bm_toggle_author_donations_posts_callback',  
        'bitmate_author_donations_display_options',   
        'bitmate_author_donations',          
        array(                                
            'Enable this to automatically display the BitMate Author Donations box after posts.'  
        )  
    );  
      
    add_settings_field(   
        'display_bm_author_credit',                       
        'Display BitMate Credit Link',                
        'bm_toggle_author_donations_credit_callback',    
        'bitmate_author_donations_display_options',                            
        'bitmate_author_donations',           
        array(                                
            'We\'d really appreciate this but it is not required!'  
        )  
    );   
      
	register_setting(
		'bitmate_author_donations_display_options',
		'bitmate_author_donations_display_options'
	);
  
      
}   
add_action('admin_init', 'bm_author_donations_options'); 
  
/* Generate Section and Field Callbacks */
function bm_author_donations_options_callback() {  
    echo '<p>Configure the display options below. You can also manually use the <strong>[bitmate-author-donate]</strong> shortcode anywhere on your site.</p>';  
} 

function bm_toggle_author_donations_posts_callback($args) {
	
	$options = get_option('bitmate_author_donations_display_options');
	
	$html = '<input type="checkbox" id="display_bm_post_box" name="bitmate_author_donations_display_options[display_bm_post_box]" value="1" ' . checked( 1, isset( $options['display_bm_post_box'] ) ? $options['display_bm_post_box'] : 0, false ) . '/>'; 
	
	$html .= '<label for="display_bm_post_box">'  . $args[0] . '</label>'; 
	
	echo $html;
	
} 

function bm_toggle_author_donations_credit_callback($args) {
	
	$options = get_option('bitmate_author_donations_display_options');
	
	$html = '<input type="checkbox" id="display_bm_author_credit" name="bitmate_author_donations_display_options[display_bm_author_credit]" value="1" ' . checked( 1, isset( $options['display_bm_author_credit'] ) ? $options['display_bm_author_credit'] : 0, false ) . '/>'; 
	
	$html .= '<label for="display_bm_author_credit">'  . $args[0] . '</label>'; 
	
	echo $html;
	
} 

/* Adds Widget Functionality */

class BM_Donation_Widget extends WP_Widget {

	public function __construct() {
		parent::__construct(
	 		'bm_donation_widget',
			'BitMate Donations Widget',
			array( 'description' => 'A widget for collecting bitcoin donations.' ) 
		);
	}

	public function widget( $args, $instance ) {
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo $before_widget;
		?>
		<div class="bitmate-donate-widget">
			<h4 class="widget-title"><?php echo $title ?></h4>
			<?php echo do_shortcode('[bitmate-donate-widget]'); ?>
		</div>
		<?php	
		echo $after_widget;
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = strip_tags( $new_instance['title'] );
		return $instance;
	}

	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = 'Donate Bitcoin';
		}
		?>
		<p>
		<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />		
		</p>
		<?php 
	}

}

function bitmate_widgets_init(){
	register_widget( 'BM_Donation_Widget' );
}
add_action( 'widgets_init', 'bitmate_widgets_init' );